#import "PokktVideoVC.h"
#import "PokktUtility.h"


#define EarnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]


@interface PokktVideoVC ()

@property (nonatomic) float points;

@end

@implementation PokktVideoVC

- (void)viewDidLoad {
    [super viewDidLoad];
    [self updateEarnedPoints];

    
    logoImg.transform = CGAffineTransformMakeRotation(-M_1_PI);
    // Do any additional setup after loading the view.
    
    [self configurePokktSDK];
}



- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)configurePokktSDK
{
    NSUserDefaults *settings = [NSUserDefaults standardUserDefaults];
    
    NSString *appId = [settings objectForKey:@"appId"];
    NSString *securityKey = [settings objectForKey:@"secKey"];
    
    /**
     * In [PokktAds setPokktConfig: securityKey:]
     * Replace "AppID" and "SecurityKey"  with the one assigned to you by Pokkt.
     *
     */
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // optional, set it to true if you want to enable logs for PokktSDK
    
    [PokktDebugger setDebug:YES];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    //[PokktVideoAds setPokktVideoAdsDelegate:self];
}

#pragma mark UIButton Actions

-(IBAction)cacheFullScreenAd:(id)sender
{
    [PokktUtility addSpinnerOnButton:cacheRewardedBtn];
    [PokktAds cacheAd:@"e57ea400cb20da831b559f41780e9350" withDelegate:self];
}

-(IBAction)showFullScreenAd:(id)sender
{
    [PokktAds showAd:@"e57ea400cb20da831b559f41780e9350" withViewController:self withDelegate:self];
}

-(IBAction)cacheNonRewardedVideoAd:(id)sender
{
    //[PokktUtility addSpinnerOnButton:cacheNonRewardedBtn];
    //[PokktVideoAds cacheNonRewarded:screenTF.text];
}

-(IBAction)showNonRewardedVideoAd:(id)sender
{
    //[PokktVideoAds showNonRewarded:screenTF.text withViewController:self];
}

#pragma mark Textfield Delegate Method

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}


- (void)updateEarnedPoints
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
        self.rewardPointLabel.text = [NSString stringWithFormat:@"Earned Points: %.02f",self.points];
    }
}


#pragma mark Pokkt Video Ads Delegates

- (void)adCached:(NSString *)screenId withReward:(double)reward
{
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    [PokktUtility stopSpinner:cacheRewardedBtn];
    
    NSString *msg = [NSString stringWithFormat:@"Video ad caching complete for %@ with reward point is %f", screenId, reward];
    
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adFailedToCache:(NSString *)screenId errorMessage:(NSString *)errorMessage
{
    [PokktUtility stopSpinner:cacheNonRewardedBtn];
    [PokktUtility stopSpinner:cacheRewardedBtn];
    NSString *msg = [NSString stringWithFormat:@"Video ad caching failed for %@ with error is %@", screenId, errorMessage];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adClicked:(NSString *)screenId
{
    NSString *msg = [NSString stringWithFormat:@"Video ad Clicked for %@", screenId];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adClosed:(NSString *)screenId adCompleted:(BOOL)adCompleted
{
    NSString *msg = [NSString stringWithFormat:@"Video ad closed for %@, ad was completed: %@", screenId, (adCompleted ? @"YES" : @"NO")];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adDisplayed:(NSString *)screenId
{
    NSString *msg = [NSString stringWithFormat:@"Video ad displayed for %@", screenId];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adFailedToShow:(NSString *)screenId errorMessage:(NSString *)errorMessage
{
    NSString *msg = [NSString stringWithFormat:@"Video ad falied to show for %@", screenId];
    [PokktDebugger showToast:msg viewController:self];
}

- (void)adGratified:(NSString *)screenId withReward:(double)reward
{
    if([userDefaluts objectForKey:EarnedPoints])
    {
        self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
    }
    if (reward > 0)
    {
        self.points += reward;
        [userDefaluts setValue:[NSString stringWithFormat:@"%f",self.points] forKey:EarnedPoints];
        [userDefaluts synchronize];
        [self updateEarnedPoints];
    }
    NSString *msg = [NSString stringWithFormat:@"Video ad gratified for %@ with reward is %f", screenId, reward];
    [PokktDebugger showToast:msg viewController:self];
}

@end
