#import "PokktMoPubCustomInterstitial.h"

@implementation PokktMoPubCustomInterstitial
@synthesize delegate;

- (void)requestInterstitialWithCustomEventInfo:(NSDictionary *)info
{
    NSLog(@"%@", info);
    
    screenName = [info objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [info objectForKey:@"POKKT_APP_ID"];
    securityKey = [info objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[info objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [info objectForKey:@"POKKT_THIRD_PARTY_USERID"];
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    [self setGDPR];
    
    [PokktAds cacheAd:screenName withDelegate:self];
}

- (void)showInterstitialFromRootViewController:(UIViewController *)rootViewController
{
    [self setGDPR];
    
    [PokktAds showAd:screenName withViewController:rootViewController withDelegate:self];
}

-(void)setGDPR
{
    PokktConsentInfo *consentInfo = [PokktAds getPokktConsentInfo];
    MPBool isGdprApplicable = [[MoPub sharedInstance] isGDPRApplicable];
    consentInfo.isGDPRApplicable = (isGdprApplicable == MPBoolYes) ? YES : NO ;
    consentInfo.isGDPRConsentAvailable = [[MoPub sharedInstance] canCollectPersonalInfo];
    [PokktAds setPokktConsentInfo:consentInfo];
}

#pragma mark Pokkt Interstitial Ads Delegates

- (void) adClosed:(NSString*) screenId adCompleted:(BOOL) adCompleted
{
    adType = No_Ad;
    [self.delegate interstitialCustomEventWillDisappear:self];
}

- (void) adClicked:(NSString*) screenId
{
    [self.delegate interstitialCustomEventDidReceiveTapEvent:self];
}

- (void)adCachingResult:(NSString *)screenId isSuccess:(BOOL)success withReward:(double)reward errorMessage:(NSString *)errorMessage {
    if([errorMessage  isEqual: @""] || success == YES) {
        adType = Interstitial_Ad;
        [self.delegate interstitialCustomEvent:self didLoadAd:nil];
    } else {
        adType = No_Ad;
        NSError *err = [NSError errorWithDomain:@"Error"
                                           code:0
                                       userInfo:@{
                                                  NSLocalizedDescriptionKey:errorMessage
                                                  }];
        [self.delegate interstitialCustomEvent:self didFailToLoadAdWithError:err];
    }
}

- (void)adDisplayResult:(NSString *)screenId isSuccess:(BOOL)success errorMessage:(NSString *)errorMessage {
    NSString *msg = @"";
    if([errorMessage  isEqual: @""] || success == YES) {
        [self.delegate interstitialCustomEventWillAppear:self];
    } else {
        msg = [NSString stringWithFormat:@"ad falied to show for %@ with error %@", screenId, errorMessage];
    }
    
    [PokktDebugger showToast:msg viewController:self];
}

@end
