#import "PokktMoPubRewardedVideo.h"

@interface PokktMoPubRewardedVideo ()
{
    NSString *pokktScreenName;
    NSString *appId;
    NSString *securityKey;
}

@end

@implementation PokktMoPubRewardedVideo

@synthesize delegate;

- (void)requestRewardedVideoWithCustomEventInfo:(NSDictionary *)info
{
    NSLog(@"%@", info);
    
    pokktScreenName = [info objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [info objectForKey:@"POKKT_APP_ID"];
    securityKey = [info objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[info objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [info objectForKey:@"POKKT_THIRD_PARTY_USERID"];
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    [self setGDPR];
   
    [PokktAds cacheAd:pokktScreenName withDelegate:self];
}

- (void)presentRewardedVideoFromViewController:(UIViewController *)viewController
{
    [self setGDPR];
    [PokktAds showAd:pokktScreenName withViewController:viewController withDelegate:self];
}

-(void)setGDPR
{
    PokktConsentInfo *consentInfo = [PokktAds getPokktConsentInfo];
    MPBool isGdprApplicable = [[MoPub sharedInstance] isGDPRApplicable];
    consentInfo.isGDPRApplicable = (isGdprApplicable == MPBoolYes) ? YES : NO ;   
    consentInfo.isGDPRConsentAvailable = [[MoPub sharedInstance] canCollectPersonalInfo];
    [PokktAds setPokktConsentInfo:consentInfo];
}

#pragma mark Pokkt Video Ads Delegates

- (void) adClosed:(NSString*) screenId adCompleted:(BOOL) adCompleted
{
    if (adCompleted) {
        [self.delegate rewardedVideoDidDisappearForCustomEvent:self];
    } else {
        [self.delegate rewardedVideoWillDisappearForCustomEvent:self];
    }
    
}

- (void) adClicked:(NSString*) screenId
{
    [self.delegate rewardedVideoDidReceiveTapEventForCustomEvent:self];
}

- (void) adFailedToShow:(NSString*) screenId errorMessage:(NSString*) errorMessage
{
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate rewardedVideoDidFailToPlayForCustomEvent:self error:err];
}

- (void) adGratified:(NSString*) screenId withReward:(double) reward
{
    MPRewardedVideoReward *rewardData = [[MPRewardedVideoReward alloc] initWithCurrencyAmount:[NSNumber numberWithFloat:reward]];
    [self.delegate rewardedVideoShouldRewardUserForCustomEvent:self reward:rewardData];
}

- (void)adCachingResult:(NSString *)screenId isSuccess:(BOOL)success withReward:(double)reward errorMessage:(NSString *)errorMessage {
    if([errorMessage  isEqual: @""] || success == YES) {
        NSLog(@"Pokkt ads cached successfully...");
        [self.delegate rewardedVideoDidLoadAdForCustomEvent:self];
    } else {
        NSError *err = [NSError errorWithDomain:@"Error"
                                           code:0
                                       userInfo:@{
                                                  NSLocalizedDescriptionKey:errorMessage
                                                  }];

        [self.delegate rewardedVideoDidFailToLoadAdForCustomEvent:self error:err];
    }
}

- (void)adDisplayResult:(NSString *)screenId isSuccess:(BOOL)success errorMessage:(NSString *)errorMessage {
    if([errorMessage  isEqual: @""] || success == YES) {
        [self.delegate rewardedVideoWillAppearForCustomEvent:self];
    } else {
        NSLog(@"Video ad falied to show for %@ with error %@", screenId, errorMessage);
    }
}

@end
